@@ -6,8 +6,11 @@ import queue
 import socket
 import ast
 import subprocess
+import dateutil.parser
+import datetime
 
 from select import select
+from slai.clients.cli import get_cli_client
 from slai_cli import log
 from slai_cli.exceptions import RetryException
 
@@ -71,6 +74,14 @@ class DockerClient:
     def __init__(self, *, project_name, project_id):
         self.project_name = project_name
         self.project_id = project_id
+
+        self.cli_client = get_cli_client()
+        self.cli_version = self.cli_client.get_cli_version()
+
+        self.earliest_image_tag_time = dateutil.parser.isoparse(
+            self.cli_version["earliest_docker_image_tag_time"]
+        )
+
         try:
             self.client = docker.from_env()
             self.docker_api_client = docker.APIClient(
@@ -91,6 +102,16 @@ class DockerClient:
             self.project_container = containers[0]
             self.project_container_id = self.project_container.id
             self.host_port = self.project_container.ports["8888/tcp"][0]["HostPort"]
+            self.last_tag_time = dateutil.parser.isoparse(
+                self.project_container.image.attrs["Metadata"]["LastTagTime"]
+            )
+
+            if self.last_tag_time < self.earliest_image_tag_time:
+                log.warn(
+                    "Project container is out of date, please update to the latest image with: `docker-compose pull`"  # noqa
+                )
+                raise RuntimeError("out_of_date_container")
+
         else:
             log.warn("Unable to connect to docker container, attempting to start...")
             try:
